Package: googleAuthR
Type: Package
Version: 2.0.2.1
Title: Authenticate and Create Google APIs
Description: Create R functions that interact with OAuth2 Google APIs 
    <https://developers.google.com/apis-explorer/> easily,
    with auto-refresh and Shiny compatibility.
Authors@R: c(person("Mark", "Edmondson",email = "m@sunholo.com",
                  role = "aut",
                  comment = c(ORCID = "0000-0002-8434-3881")),
           person("Erik", "Grönroos", email = "erik.gronroos@8-bit-sheep.com",
                  role = "cre"),
           person("Jennifer", "Bryan", email="jenny@stat.ubc.ca", role = "ctb"),
           person("Johann", "deBoer", email="johanndeboer@gmail.com", role = "ctb"),
           person("Neal", "Richardson", email="neal.p.richardson@gmail.com", role = "ctb"),
           person("David","Kulp", email="dkulp@cs.umass.edu", role = "ctb"),
           person("Joe","Cheng", email = "joe@rstudio.com", role = "ctb"))
URL: https://code.markedmondson.me/googleAuthR/
BugReports: https://github.com/MarkEdmondson1234/googleAuthR/issues
Depends: R (>= 3.3.0)
Imports: assertthat (>= 0.2.0), cli (>= 2.0.2), digest, gargle (>=
        1.2.0), httr (>= 1.4.0), jsonlite (>= 1.6), memoise (>= 1.1.0),
        rlang, utils
Suggests: covr, devtools (>= 1.12.0), formatR (>= 1.4),
        googleAnalyticsR, knitr, miniUI (>= 0.1.1), rmarkdown, roxygen2
        (>= 5.0.0), rstudioapi, shiny (>= 0.13.2), testthat, usethis
        (>= 1.6.0)
License: MIT + file LICENSE
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.3.1
NeedsCompilation: no
Packaged: 2026-01-09 08:46:10 UTC; hornik
Author: Mark Edmondson [aut] (ORCID: <https://orcid.org/0000-0002-8434-3881>),
  Erik Grönroos [cre],
  Jennifer Bryan [ctb],
  Johann deBoer [ctb],
  Neal Richardson [ctb],
  David Kulp [ctb],
  Joe Cheng [ctb]
Maintainer: Erik Grönroos <erik.gronroos@8-bit-sheep.com>
Repository: CRAN
Date/Publication: 2026-01-09 09:00:22 UTC
Built: R 4.6.0; ; 2026-04-26 06:49:45 UTC; unix
