# Generated by roxygen2: do not edit by hand

S3method(print,gar_parse_error)
export(gar_api_generator)
export(gar_api_key)
export(gar_api_page)
export(gar_attach_auto_auth)
export(gar_auth)
export(gar_auth_configure)
export(gar_auth_service)
export(gar_auto_auth)
export(gar_batch)
export(gar_batch_walk)
export(gar_cache_empty)
export(gar_cache_get_loc)
export(gar_cache_setup)
export(gar_check_existing_token)
export(gar_create_api_objects)
export(gar_create_api_skeleton)
export(gar_create_package)
export(gar_deauth)
export(gar_debug_parsing)
export(gar_discovery_api)
export(gar_discovery_apis_list)
export(gar_gce_auth)
export(gar_gce_auth_default)
export(gar_gce_auth_email)
export(gar_has_token)
export(gar_oauth_app)
export(gar_scope_config)
export(gar_service_create)
export(gar_service_get)
export(gar_service_get_roles)
export(gar_service_grant_roles)
export(gar_service_key)
export(gar_service_key_list)
export(gar_service_list)
export(gar_service_provision)
export(gar_set_client)
export(gar_setup_auth_check)
export(gar_setup_auth_key)
export(gar_setup_check_session)
export(gar_setup_clientid)
export(gar_setup_edit_renviron)
export(gar_setup_env_check)
export(gar_setup_get_authenv)
export(gar_setup_menu)
export(gar_setup_menu_do)
export(gar_shiny_auth)
export(gar_shiny_auth_url)
export(gar_shiny_login_ui)
export(gar_shiny_ui)
export(gar_token)
export(gar_token_info)
export(googleSignIn)
export(googleSignInUI)
export(silent_auth)
export(skip_if_no_env_auth)
import(assertthat)
import(cli)
import(memoise)
importFrom(assertthat,assert_that)
importFrom(assertthat,is.string)
importFrom(cli,cli_alert_danger)
importFrom(cli,cli_alert_info)
importFrom(cli,cli_alert_success)
importFrom(cli,cli_alert_warning)
importFrom(cli,cli_code)
importFrom(cli,cli_li)
importFrom(cli,cli_rule)
importFrom(cli,cli_ul)
importFrom(digest,digest)
importFrom(gargle,credentials_app_default)
importFrom(gargle,credentials_gce)
importFrom(gargle,credentials_service_account)
importFrom(gargle,gargle_oauth_sitrep)
importFrom(gargle,oauth_app_from_json)
importFrom(gargle,token_fetch)
importFrom(httr,POST)
importFrom(httr,Token2.0)
importFrom(httr,add_headers)
importFrom(httr,config)
importFrom(httr,content)
importFrom(httr,headers)
importFrom(httr,modify_url)
importFrom(httr,oauth_app)
importFrom(httr,oauth_endpoints)
importFrom(httr,set_config)
importFrom(httr,stop_for_status)
importFrom(httr,user_agent)
importFrom(httr,with_verbose)
importFrom(jsonlite,fromJSON)
importFrom(rlang,is_string)
importFrom(tools,file_ext)
importFrom(utils,URLencode)
importFrom(utils,browseURL)
importFrom(utils,menu)
importFrom(utils,modifyList)
importFrom(utils,packageVersion)
